@@ -1,60 +1,60 @@
 from typing import List, Optional
 from ddd_objects.domain.entity import Entity, ExpiredEntity
 from .value_obj import (
-    Data,
-    Number,
-    PayType,
-    ID,
-    SecurityGroupID,
-    Size,
-    Price,
     KeyType,
-    Subdomain,
-    NodeStatus,
-    Token,
-    NodeName,
-    BandWidth,
-    InstanceType,
-    RegionID,
-    Type,
-    Name,
-    TimeInterval,
-    Version,
-    GPUType,
-    InternetPayType,
-    DomainName,
-    Endpoint,
-    IP,
-    Key,
-    RecordID,
-    Time,
-    Path,
-    Usage,
-    Username,
-    InstanceTypeStatusCategory,
-    InstanceID,
-    DNSType,
-    ServiceType,
-    Output,
     NodeType,
-    Weight,
-    Hostname,
-    Info,
     Bool,
-    DateTime,
-    Command,
-    NodeLabel,
-    InstanceTypeStatus,
     DNSLine,
-    IngressHost,
-    Status,
-    Port,
-    Password,
-    ImageID,
+    Username,
+    Token,
+    RegionID,
+    Key,
+    InternetPayType,
+    Endpoint,
+    Time,
     ZoneID,
+    InstanceTypeStatus,
+    Usage,
+    TimeInterval,
+    BandWidth,
+    PayType,
+    Path,
+    Value,
+    DateTime,
+    IngressHost,
+    Name,
+    Info,
+    Weight,
+    NodeStatus,
+    RecordID,
+    InstanceType,
+    NodeLabel,
+    Version,
+    NodeName,
     InstanceName,
+    Size,
+    Data,
+    GPUType,
+    ServiceType,
+    Password,
+    IP,
+    ImageID,
+    Hostname,
+    SecurityGroupID,
+    DNSType,
+    Number,
+    Subdomain,
+    Command,
+    InstanceID,
+    Port,
+    DomainName,
+    Status,
     PodStatus,
-    Value
+    Output,
+    Type,
+    InstanceTypeStatusCategory,
+    ID,
+    Price
 )
 
 class Condition(Entity):
@@ -226,7 +226,8 @@ class NodeUserSetting(Entity):
         random_password: Bool = Bool(True),
         internet_pay_type: Type = Type('PayByTraffic'),
         master_ip: Optional[IP] = None,
-        inner_connection: Bool = Bool(True)
+        inner_connection: Bool = Bool(True),
+        amount: Number = Number(1)
     ):
         self.name=name
         self.k3s_token=k3s_token
@@ -242,6 +243,7 @@ class NodeUserSetting(Entity):
         self.internet_pay_type=internet_pay_type
         self.master_ip=master_ip
         self.inner_connection=inner_connection
+        self.amount=amount
 
 class NodeInfo(ExpiredEntity):
     def __init__(
