@@ -2,111 +2,111 @@ from shutil import disk_usage
 from typing import List
 from ddd_objects.infrastructure.converter import Converter
 from ..domain.entity import (
-    Condition,
-    Ingress,
     PodContainer,
-    NodeMeta,
-    Service,
-    NodeInfo,
+    Deployment,
+    InstanceUserSetting,
     SecretUserSetting,
+    Ingress,
+    InstanceInfo,
+    Condition,
+    DNSRecord,
+    InstanceTypeUserSetting,
+    Pod,
+    ConfigMapUserSetting,
+    PodOSSOperationInfo,
+    Service,
+    InstanceTypeWithStatus,
+    ResourceOSSSetting,
     Namespace,
     CommandSetting,
-    Secret,
-    InstanceUserSetting,
-    ConfigMap,
-    DNSRecord,
-    ResourceOSSSetting,
-    Deployment,
-    Pod,
-    CommandResult,
-    ConfigMapUserSetting,
-    InstanceTypeWithStatus,
-    PodOSSOperationInfo,
-    InstanceTypeUserSetting,
-    OSSOperationInfo,
     NodeUserSetting,
-    InstanceInfo
+    OSSOperationInfo,
+    Secret,
+    NodeMeta,
+    CommandResult,
+    ConfigMap,
+    NodeInfo
 )
 from ..domain.value_obj import (
-    Data,
-    Number,
-    PayType,
-    ID,
-    SecurityGroupID,
-    Size,
-    Price,
     KeyType,
-    Subdomain,
-    NodeStatus,
-    Token,
-    NodeName,
-    BandWidth,
-    InstanceType,
-    RegionID,
-    Type,
-    Name,
-    TimeInterval,
-    Version,
-    GPUType,
-    InternetPayType,
-    DomainName,
-    Endpoint,
-    IP,
-    Key,
-    RecordID,
-    Time,
-    Path,
-    Usage,
-    Username,
-    InstanceTypeStatusCategory,
-    InstanceID,
-    DNSType,
-    ServiceType,
-    Output,
     NodeType,
-    Weight,
-    Hostname,
-    Info,
     Bool,
-    DateTime,
-    Command,
-    NodeLabel,
-    InstanceTypeStatus,
     DNSLine,
-    Status,
-    Port,
-    Password,
-    ImageID,
+    Username,
+    Token,
+    RegionID,
+    Key,
+    InternetPayType,
+    Endpoint,
+    Time,
     ZoneID,
+    InstanceTypeStatus,
+    Usage,
+    TimeInterval,
+    BandWidth,
+    PayType,
+    Path,
+    Value,
+    DateTime,
+    Name,
+    Info,
+    Weight,
+    NodeStatus,
+    RecordID,
+    InstanceType,
+    NodeLabel,
+    Version,
+    NodeName,
     InstanceName,
+    Size,
+    Data,
+    GPUType,
+    ServiceType,
+    Password,
+    IP,
+    ImageID,
+    Hostname,
+    SecurityGroupID,
+    DNSType,
+    Number,
+    Subdomain,
+    Command,
+    InstanceID,
+    Port,
+    DomainName,
+    Status,
     PodStatus,
-    Value
+    Output,
+    Type,
+    InstanceTypeStatusCategory,
+    ID,
+    Price
 )
 from .do import (
-    PodDO,
-    NodeUserSettingDO,
-    ConfigMapUserSettingDO,
-    IngressDO,
-    PodOSSOperationInfoDO,
-    NodeMetaDO,
-    InstanceTypeWithStatusDO,
-    CommandResultDO,
-    NodeInfoDO,
-    NamespaceDO,
-    OSSOperationInfoDO,
-    InstanceTypeUserSettingDO,
-    InstanceInfoDO,
-    ResourceOSSSettingDO,
-    SecretDO,
-    DeploymentDO,
-    InstanceUserSettingDO,
-    SecretUserSettingDO,
     DNSRecordDO,
-    ServiceDO,
+    NamespaceDO,
+    IngressDO,
+    NodeUserSettingDO,
+    CommandResultDO,
     ConfigMapDO,
-    PodContainerDO,
     ConditionDO,
-    CommandSettingDO
+    DeploymentDO,
+    NodeInfoDO,
+    OSSOperationInfoDO,
+    ResourceOSSSettingDO,
+    PodContainerDO,
+    InstanceTypeWithStatusDO,
+    NodeMetaDO,
+    CommandSettingDO,
+    SecretUserSettingDO,
+    SecretDO,
+    InstanceInfoDO,
+    ServiceDO,
+    PodOSSOperationInfoDO,
+    PodDO,
+    InstanceTypeUserSettingDO,
+    InstanceUserSettingDO,
+    ConfigMapUserSettingDO
 )
 
 class ConditionConverter(Converter):
@@ -167,7 +167,8 @@ class NodeUserSettingConverter(Converter):
             random_password = Bool(do.random_password),
             internet_pay_type = Type(do.internet_pay_type),
             master_ip = IP(do.master_ip),
-            inner_connection = Bool(do.inner_connection)
+            inner_connection = Bool(do.inner_connection),
+            amount = Number(do.amount)
         )
     def to_do(self, x: NodeUserSetting):
         return NodeUserSettingDO(
@@ -184,7 +185,8 @@ class NodeUserSettingConverter(Converter):
             random_password = None if x.random_password is None else x.random_password.get_value(),
             internet_pay_type = None if x.internet_pay_type is None else x.internet_pay_type.get_value(),
             master_ip = None if x.master_ip is None else x.master_ip.get_value(),
-            inner_connection = None if x.inner_connection is None else x.inner_connection.get_value()
+            inner_connection = None if x.inner_connection is None else x.inner_connection.get_value(),
+            amount = None if x.amount is None else x.amount.get_value()
         )
 
 class NamespaceConverter(Converter):
@@ -365,16 +367,16 @@ class NodeInfoConverter(Converter):
             security_group_id = [SecurityGroupID(m) for m in do.security_group_id],
             node_label = NodeLabel(do.node_label),
             cpu_number = Number(do.cpu_number),
-            cpu_usage = None if do.cpu_usage is None else Usage(do.cpu_usage),
-            memory_size = None if do.memory_size is None else Size(do.memory_size),
-            actual_memory_size = None if do.actual_memory_size is None else Size(do.actual_memory_size),
-            memory_usage = None if do.memory_usage is None else Size(do.memory_usage),
-            flow_in = None if do.flow_in is None else Size(do.flow_in),
-            flow_out = None if do.flow_out is None else Size(do.flow_out),
-            disk_size = None if do.disk_size is None else Size(do.disk_size),
-            disk_usage = None if do.disk_usage is None else Usage(do.disk_usage),
-            io_in = None if do.io_in is None else Number(do.io_in),
-            io_out = None if do.io_out is None else Number(do.io_out),
+            cpu_usage = Usage(do.cpu_usage),
+            memory_size = Size(do.memory_size),
+            actual_memory_size = Size(do.actual_memory_size),
+            memory_usage = Size(do.memory_usage),
+            flow_in = Size(do.flow_in),
+            flow_out = Size(do.flow_out),
+            disk_size = Size(do.disk_size),
+            disk_usage = Usage(do.disk_usage),
+            io_in = Number(do.io_in),
+            io_out = Number(do.io_out),
             gpu_type = GPUType(do.gpu_type),
             gpu_number = Number(do.gpu_number),
             instance_type_status = InstanceTypeStatus(do.instance_type_status),
