@@ -96,12 +96,12 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
             self.log_func(result.error_traceback)
             return None
 
-    def create_node(self, condition: Condition, node_user_setting: NodeUserSetting)->Optional[NodeInfo]:
+    def create_node(self, condition: Condition, node_user_setting: NodeUserSetting)->Optional[List[NodeInfo]]:
         condition = condition_converter.to_do(condition)
         node_user_setting = node_user_setting_converter.to_do(node_user_setting)
         result = self.ao.create_node(condition, node_user_setting)
         if result.succeed:
-            return node_info_converter.to_entity(result.get_value())
+            return [node_info_converter.to_entity(x) for x in result.get_value()]
         else:
             self.log_func(result.error_traceback)
             return None
